Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(511)

Unified Diff: pkg/dartino_compiler/lib/input_handler.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/dartino_compiler/lib/incremental_backend.dart ('k') | pkg/dartino_compiler/lib/program_info.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/dartino_compiler/lib/input_handler.dart
diff --git a/pkg/fletchc/lib/input_handler.dart b/pkg/dartino_compiler/lib/input_handler.dart
similarity index 99%
rename from pkg/fletchc/lib/input_handler.dart
rename to pkg/dartino_compiler/lib/input_handler.dart
index c21f3fcbb665ae4d8eed7d549992ed9d7d69ea9f..529dfbae6055929e4613a198897b53af99e1312e 100644
--- a/pkg/fletchc/lib/input_handler.dart
+++ b/pkg/dartino_compiler/lib/input_handler.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-part of fletch.vm_session;
+part of dartino.vm_session;
const String BANNER = """
Starting session. Type 'help' for a list of commands.
@@ -401,7 +401,7 @@ class InputHandler {
}
// This method is used to deal with the stopped process command responses
// that can be returned when sending the Fletch VM a command request.
Future handleProcessStopResponse(
VmCommand response,
SessionState state) async {
@@ -401,7 +401,7 @@ class InputHandler {
}
// This method is used to deal with the stopped process command responses
- // that can be returned when sending the Fletch VM a command request.
+ // that can be returned when sending the Dartino VM a command request.
Future handleProcessStopResponse(
VmCommand response,
« no previous file with comments | « pkg/dartino_compiler/lib/incremental_backend.dart ('k') | pkg/dartino_compiler/lib/program_info.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698